## MNIST SEPARATOR
**mnist-separator** is a new technology for recognizing handwritten numbers of the MNIST dataset

### Installation
```
pip install mnist-separator
```
[Here](https://kravtsov-development.medium.com/new-method-for-recognizing-handwritten-digits-mnist-dataset-c6f83e5291ee) we show how to use it 
